@@ -8,12 +8,12 @@
 
 use crate::{AmountSecrets, KeyImage, Owner, SpentProof, TransactionVerifier};
 use crate::{DbcContent, DerivationIndex, Error, KeyManager, Result};
-use blsttc::SecretKey;
-use sn_ringct::{
+use bls_ringct::{
     group::Curve,
     ringct::{OutputProof, RingCtTransaction},
     {RevealedCommitment, TrueInput},
 };
+use blsttc::SecretKey;
 use std::collections::BTreeSet;
 use std::convert::TryFrom;
 use tiny_keccak::{Hasher, Sha3};
@@ -136,7 +136,7 @@ impl Dbc {
     /// This is useful for checking if a Dbc has been spent.
     pub fn key_image(&self, base_sk: &SecretKey) -> Result<KeyImage> {
         let secret_key = self.owner_once(base_sk)?.secret_key()?;
-        Ok(sn_ringct::key_image(secret_key).to_affine().into())
+        Ok(bls_ringct::key_image(secret_key).to_affine().into())
     }
 
     /// returns KeyImage for the owner's derived public key
@@ -264,9 +264,10 @@ pub(crate) mod tests {
     use crate::{
         mock,
         rand::{CryptoRng, RngCore},
-        Amount, AmountSecrets, DbcBuilder, Hash, Owner, OwnerOnce, SpentProofContent,
+        Amount, AmountSecrets, DbcBuilder, GenesisMaterial, Hash, Owner, OwnerOnce,
+        SpentProofContent,
     };
-    use sn_ringct::{ringct::RingCtMaterial, sn_bulletproofs::PedersenGens, Output};
+    use bls_ringct::{bls_bulletproofs::PedersenGens, ringct::RingCtMaterial, Output};
 
     fn divide(amount: Amount, n_ways: u8) -> impl Iterator<Item = Amount> {
         (0..n_ways).into_iter().map(move |i| {
@@ -342,7 +343,7 @@ pub(crate) mod tests {
 
         assert!(matches!(
             dbc.verify(&owner_once.owner_base().secret_key()?, &key_manager),
-            Err(Error::RingCt(sn_ringct::Error::TransactionMustHaveAnInput))
+            Err(Error::RingCt(bls_ringct::Error::TransactionMustHaveAnInput))
         ));
 
         Ok(())
@@ -586,7 +587,7 @@ pub(crate) mod tests {
                     .iter()
                     .any(|o| dbc_owner.eq(o.public_key())));
             }
-            Err(Error::RingCt(sn_ringct::Error::TransactionMustHaveAnInput)) => {
+            Err(Error::RingCt(bls_ringct::Error::TransactionMustHaveAnInput)) => {
                 assert_eq!(n_inputs.coerce::<u8>(), 0);
             }
             Err(Error::AmountCommitmentsDoNotMatch) => {
@@ -622,7 +623,7 @@ pub(crate) mod tests {
         let (mut spentbook_node, genesis_dbc, _genesis_material, _amount_secrets) =
             mock::GenesisBuilder::init_genesis_single(rng)?;
 
-        let output_amounts = vec![amount, sn_dbc::GenesisMaterial::GENESIS_AMOUNT - amount];
+        let output_amounts = vec![amount, GenesisMaterial::GENESIS_AMOUNT - amount];
 
         let mut dbc_builder = crate::TransactionBuilder::default()
             .set_require_all_decoys(false)
