@@ -71,13 +71,13 @@ mod tests {
         let check_error = |error: Error| -> Result<()> {
             match error {
                 Error::RingCt(
-                    sn_ringct::Error::InputPseudoCommitmentsDoNotSumToOutputCommitments,
+                    bls_ringct::Error::InputPseudoCommitmentsDoNotSumToOutputCommitments,
                 ) => {
                     // Verify that no outputs were present and we got correct verification error.
                     assert_eq!(n_outputs, 0);
                     Ok(())
                 }
-                Error::RingCt(sn_ringct::Error::InvalidHiddenCommitmentInRing) => {
+                Error::RingCt(bls_ringct::Error::InvalidHiddenCommitmentInRing) => {
                     // Verify that no outputs were present and we got correct verification error.
                     assert_eq!(n_outputs, 0);
                     Ok(())
@@ -183,7 +183,7 @@ mod tests {
         let check_tx_error = |error: Error| -> Result<()> {
             match error {
                 Error::RingCt(
-                    sn_ringct::Error::InputPseudoCommitmentsDoNotSumToOutputCommitments,
+                    bls_ringct::Error::InputPseudoCommitmentsDoNotSumToOutputCommitments,
                 ) => {
                     // Verify that no inputs were present and we got correct verification error.
                     assert!(input_amounts.is_empty());
@@ -246,7 +246,7 @@ mod tests {
                     assert!(!invalid_spent_proofs.is_empty());
                 }
                 Error::RingCt(
-                    sn_ringct::Error::InputPseudoCommitmentsDoNotSumToOutputCommitments,
+                    bls_ringct::Error::InputPseudoCommitmentsDoNotSumToOutputCommitments,
                 ) => {
                     if GenesisMaterial::GENESIS_AMOUNT == output_total_amount {
                         // This can correctly occur if there are 0 outputs and inputs sum to zero.
@@ -259,10 +259,10 @@ mod tests {
                         assert!(!input_amounts.is_empty());
                     }
                 }
-                Error::RingCt(sn_ringct::Error::InvalidHiddenCommitmentInRing) => {
+                Error::RingCt(bls_ringct::Error::InvalidHiddenCommitmentInRing) => {
                     assert!(!invalid_spent_proofs.is_empty());
                 }
-                Error::RingCt(sn_ringct::Error::TransactionMustHaveAnInput) => {
+                Error::RingCt(bls_ringct::Error::TransactionMustHaveAnInput) => {
                     assert_eq!(input_amounts.len(), 0);
                 }
                 Error::FailedSignature => {
@@ -550,7 +550,7 @@ mod tests {
 
         for (key_image, tx) in dbc_builder_fudged.inputs() {
             match spentbook.log_spent(key_image, tx) {
-                Err(Error::RingCt(sn_ringct::Error::InvalidHiddenCommitmentInRing)) => {}
+                Err(Error::RingCt(bls_ringct::Error::InvalidHiddenCommitmentInRing)) => {}
                 _ => panic!("Expecting RingCt Error::InvalidHiddenCommitmentInRing"),
             }
         }
@@ -571,7 +571,7 @@ mod tests {
         let result_fudged = dbc_builder_fudged.build(&spentbook.key_manager);
 
         match result_fudged {
-            Err(Error::RingCt(sn_ringct::Error::InvalidHiddenCommitmentInRing)) => {}
+            Err(Error::RingCt(bls_ringct::Error::InvalidHiddenCommitmentInRing)) => {}
             _ => panic!("Expecting RingCt Error::InvalidHiddenCommitmentInRing"),
         }
 
